|
Boost-Commit : |
Subject: [Boost-commit] svn:boost r85532 - trunk/libs/log/src
From: andrey.semashev_at_[hidden]
Date: 2013-08-31 07:44:25
Author: andysem
Date: 2013-08-31 07:44:25 EDT (Sat, 31 Aug 2013)
New Revision: 85532
URL: http://svn.boost.org/trac/boost/changeset/85532
Log:
Fixed compilation of the generic implementation of the unhandled_exception_count function. Should fix MinGW 4.4.
Text files modified:
trunk/libs/log/src/unhandled_exception_count.cpp | 4 ++--
1 files changed, 2 insertions(+), 2 deletions(-)
Modified: trunk/libs/log/src/unhandled_exception_count.cpp
==============================================================================
--- trunk/libs/log/src/unhandled_exception_count.cpp Sat Aug 31 07:21:50 2013 (r85531)
+++ trunk/libs/log/src/unhandled_exception_count.cpp 2013-08-31 07:44:25 EDT (Sat, 31 Aug 2013) (r85532)
@@ -31,7 +31,7 @@
#if defined(BOOST_LOG_HAS_CXXABI_H)
// MinGW GCC 4.4 seem to not work the same way the newer GCC versions do. As a result, __cxa_get_globals based implementation will always return 0.
// Just disable it for now and fall back to std::unhandled_exception().
#if !defined(__MINGW32__) || (defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 5)))
// Only GCC 4.7 declares __cxa_get_globals() in cxxabi.h, older compilers do not expose this function but it's there
#define BOOST_LOG_HAS_CXA_GET_GLOBALS
@@ -55,7 +55,7 @@
return *(reinterpret_cast< const unsigned int* >(static_cast< const char* >(_getptd()) + (sizeof(void*) == 8 ? 0x100 : 0x90))); // _tiddata::_ProcessingThrow, x32 offset - 0x90, x64 - 0x100
#else
// Portable implementation. Does not allow to detect multiple nested exceptions.
- return static_cast< unsigned int >(std::unhandled_exception());
+ return static_cast< unsigned int >(std::uncaught_exception());
#endif
}
Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
@@ -31,7 +31,7 @@
#if defined(BOOST_LOG_HAS_CXXABI_H)
// MinGW GCC 4.4 seem to not work the same way the newer GCC versions do. As a result, __cxa_get_globals based implementation will always return 0.
-// Just disable it for now and fall back to std::unhandled_exception().
+// Just disable it for now and fall back to std::uncaught_exception().
#if !defined(__MINGW32__) || (defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 5)))
// Only GCC 4.7 declares __cxa_get_globals() in cxxabi.h, older compilers do not expose this function but it's there